Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ExecCommand = exec.Command
ExecCommand is exec.Command by default, but can be overridden in tests.
Functions ¶
func CompressPDF ¶
CompressPDF invokes Ghostscript with GS_COMPAT and GS_SETTINGS env vars. It is a thin wrapper over CompressPDFWithProgress without progress updates.
func CompressPDFWithProgress ¶ added in v1.1.1
CompressPDFWithProgress runs Ghostscript and reports progress via the callback. progress is called with the current page and total pages processed.
func GetPDFPageCount ¶ added in v1.5.0
GetPDFPageCount returns the number of pages in a PDF file using ghostscript
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.